==> haskell-x11-1.8-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.8
id: X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
key: X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
indefinite: False
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
abi: d42095e6df3db8f22e7846b4fbf85785
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/X11-1.8
hs-libraries: HSX11-1.8-JnAOOA5ca1mBqz6w5LwuYT
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.2.2/site-local/X11-1.8/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.10.1.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.8-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.8
id: X11-1.8-2GHfNeKQbxBLmODzL3h52l
key: X11-1.8-2GHfNeKQbxBLmODzL3h52l
license: BSD-3-Clause
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/xmonad/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
abi: df78d8dd4525eaeb828f2cd3c7b642a4
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr
hidden-modules: Graphics.X11.Xlib.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/X11-1.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/X11-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/X11-1.8
hs-libraries: HSX11-1.8-2GHfNeKQbxBLmODzL3h52l
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.4.3/site-local/X11-1.8/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.11.1.0 data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
